Revert "cmd/internal/gc: add internConcat for alloc-free string concatenation"

This reverts commit 42fcc6fea03673eeed1447eaab78a7df9385246e.

Change-Id: If860b7cbff5b5d288c1df1405c1765275dfba7cb
Reviewed-on: https://go-review.googlesource.com/7860
Reviewed-by: Russ Cox <rsc@golang.org>
diff --git a/src/cmd/internal/gc/subr.go b/src/cmd/internal/gc/subr.go
index 43aa382..32486c7 100644
--- a/src/cmd/internal/gc/subr.go
+++ b/src/cmd/internal/gc/subr.go
@@ -3574,10 +3574,10 @@
 	return false
 }
 
 // IET returns "T" if t is a concrete type, "I" if t is an interface type, and
 // "E" if t is an empty interface type.
 // It is used to build calls to the conv* and assert* runtime routines.
-func (t *Type) IET() string {
+func type2IET(t *Type) string {
 	if isnilinter(t) {
 		return "E"
 	}
@@ -3574,10 +3574,10 @@
 }
 
-// IET returns "T" if t is a concrete type, "I" if t is an interface type, and
-// "E" if t is an empty interface type.
+// type2IET returns "T" if t is a concrete type,
+// "I" if t is an interface type, and "E" if t is an empty interface type.
 // It is used to build calls to the conv* and assert* runtime routines.